@@ -3,8 +3,7 @@ from __future__ import division
 
 __author__ = 'jerryzhujian@gmail.com'
 
-__doc__ = """
-An enhancement to pandas module.
+__doc__ = """An enhancement to pandas module.
 This is kungfu, with monkey-patched common methods to (Data)Frame and Series in pandas.
 =============================================
 jerryzhujian9_at_gmail.com
